# Richdata
Helpers for Data Engineering


## Install
```shell
pip install Richdata
```

```shell
pip install Richdata[sqlserver]
```

```shell
pip install Richdata[postgres]
```

```shell
pip install Richdata[bigquery]
```

```shell
pip install Richdata[sqlserver,postgres,bigquery]
```

## Sample SQLServer
comming son

## Sample PostgreSQL
comming son
## Sample Bigquery
comming son

## Sample MongoDB
work in progress

## Sample MySQL
work in progress
